@@ -9,7 +9,7 @@
 #' @param Genus Request all species in this taxonomic Genus
 #' @param Species Request all species in this taxonomic Species
 #' @param SpecCode Request species name of species matching this SpecCode
-#' @param server fishbase or 
+#' @param server fishbase or sealifebase
 #' @examples
 #' \donttest{
 #' ## All species in the Family 
@@ -58,28 +58,8 @@ species_list <- function(Class = NULL,
   if(!is.null(SpecCode)) 
     taxa <- taxa %>% filter(SpecCode %in% !!spec_code)
   
-  taxa$Species
+  taxa %>% pull(Species)
 
 }
 
 
-
-# speccodes
-#
-# Returns SpecCodes given a list of species. Primarily for internal use
-# 
-# @examples
-# who <- species_list(Family='Scaridae')
-# speccodes(who)
-speccodes <- function(species_list, db = fb_species(server), server = NULL){ 
-  
-    if(is.integer(species_list))
-      return(dplyr::data_frame(SpecCode = species_list))
-    
-    left_join(dplyr::data_frame(Species = species_list),
-              db, by = "Species") %>%
-      select(SpecCode)
-  
-  
-}
-
