@@ -15,6 +15,9 @@ test_that("Custom queries give desired result", {
   expect_is(df, "tbl")
 
   references()
+  rr <- references(codes = c(1, 4))
+  expect_is(rr, "tbl")
+  expect_equal(nrow(rr), 2)
   
   df <- species_names(2)
   expect_is(df, "tbl")
