@@ -2,6 +2,7 @@ context("species list")
 
 test_that("We can pass a species_list based on taxanomic group", {
   
+  needs_api()
   fish <- species_list(Genus = "Labroides") 
   expect_is(fish, "character")
   expect_gt(length(fish), 1)
@@ -10,7 +11,9 @@ test_that("We can pass a species_list based on taxanomic group", {
 
 test_that("Look up species by SpecCode", {
   
-  fish <- species_list(SpecCode = 5537) 
+  needs_api()
+  
+  fish <- species_list(SpecCode = "5537") 
   expect_is(fish, "character")
   expect_equal(fish, "Bolbometopon muricatum")
   
